@@ -48,6 +48,9 @@ char audiopath[PATH_MAX] = "\0";
 char videopath[PATH_MAX] = "\0";
 char picturepath[PATH_MAX] = "\0";
 char kmlurl[PATH_MAX] = "\0";
+char pretrigger[PATH_MAX] = "\0";
+char posttrigger[PATH_MAX] = "\0";
+int max_recent_files = 30;
 
 #define PORT_PCLINK	8000
 #define PORT_KML	8888
@@ -60,7 +63,7 @@ static void server_shutdown(int signal)
 
 static void kill_children(int signal)
 {
-	while(waitpid(-1, NULL, WNOHANG) > 0) ;
+	while(waitpid(0, NULL, WNOHANG) > 0) ;
 }
 
 static int parse_config(void)
@@ -98,6 +101,7 @@ static int parse_config(void)
 	while (fgets(buffer, sizeof(buffer), f) != NULL) {
 		char option[512], value[512];
 		char *b = buffer;
+		int rel_path = 0;
 
 		for(; *b == ' ' || *b == '\t' || *b == '\n'; b++);
 		if (b[0] == '#')
@@ -110,28 +114,43 @@ static int parse_config(void)
 			return 1;
 		}
 
-		if (strcmp(option, "audiopath") == 0) {
+		if (!strcmp(option, "audiopath")) {
 			strncpy(audiopath, value, sizeof(audiopath));
 			audiopath[sizeof(audiopath) - 1] = '\0';
+			rel_path = (value[0] != '/');
 		}
-		else if (strcmp(option, "videopath") == 0) {
+		else if (!strcmp(option, "videopath")) {
 			strncpy(videopath, value, sizeof(videopath));
 			audiopath[sizeof(audiopath) - 1] = '\0';
+			rel_path = (value[0] != '/');
 		}
-		else if (strcmp(option, "picturepath") == 0) {
+		else if (!strcmp(option, "picturepath")) {
 			strncpy(picturepath, value, sizeof(picturepath));
 			picturepath[sizeof(picturepath) - 1] = '\0';
+			rel_path = (value[0] != '/');
 		}
-		else if (strcmp(option, "kmlurl") == 0) {
+		else if (!strcmp(option, "kmlurl")) {
 			strncpy(kmlurl, value, sizeof(kmlurl));
 			kmlurl[sizeof(kmlurl) - 1] = '\0';
 		}
+		else if (!strcmp(option, "pretrigger")) {
+			strncpy(pretrigger, value, sizeof(pretrigger));
+			pretrigger[sizeof(pretrigger) - 1] = '\0';
+			rel_path = (value[0] != '/');
+		}
+		else if (!strcmp(option, "posttrigger")) {
+			strncpy(posttrigger, value, sizeof(posttrigger));
+			posttrigger[sizeof(posttrigger) - 1] = '\0';
+			rel_path = (value[0] != '/');
+		}
+		else if (!strcmp(option, "max_recent_files"))
+			max_recent_files = abs(atoi(value));
 		else {
 			printf("unknown option in config file: %s\n", option);
 			return 1;
 		}
 
-		if (strcmp(option, "kmlurl") && value[0] != '/') {
+		if (rel_path) {
 			printf("paths must be absolute refs in config file: %s\n", value);
 			return 1;
 		}
@@ -222,17 +241,17 @@ static void udp_responder (int sd) {
 
 	if (recvfrom(sd, buf, sizeof(buf), 0, (struct sockaddr*)&sin, &sinlen) < 0) {
 		log("recvfrom: %s", strerror(errno));
-		return;	// exit gracefully
+		return;	/* exit gracefully */
 	}
 
 	if (strstr(buf, "ARE_YOU_KISS_PCLINK_SERVER?")) {
 		char hostname[255];
 
-		log("Received identity request from %s", inet_ntoa(sin.sin_addr));
+		logv("Received identity request from %s", inet_ntoa(sin.sin_addr));
 
 		if (gethostname(hostname, sizeof(hostname)) < 0) {
 			log("gethostname: %s", strerror(errno));
-			return; // exit gracefully
+			return; /* exit gracefully */
 		}
 		strcat(hostname, " running kissd-");
 		strcat(hostname, KISSD_VERSION);
@@ -305,14 +324,12 @@ again:
 		exit(1);
 	case 0:
 		close(sd_server);
-		if (v_opt)
-			log("%s", "KiSS started connection");
+		logv("%s", "KiSS started connection");
 		if (FD_ISSET(sd_pclink, &set))
 			handle_request(sd_client);
 		else
 			handle_kmlrequest(sd_client);
-		if (v_opt)
-			log("%s", "KiSS closed connection");
+		logv("%s", "KiSS closed connection");
 		exit(0);
     	default:
 		close(sd_client);
