@@ -30,12 +30,23 @@ extern char audiopath[];
 extern char videopath[];
 extern char picturepath[];
 extern char kmlurl[];
+extern char pretrigger[];
+extern char posttrigger[];
+extern int max_recent_files;
 
-#define KISSD_VERSION "version 0.9, Sep 27, 2005"
+#define KISSD_VERSION "version 0.12, Sep 23, 2006"
 
 void handle_request(int sock);
 void handle_kmlrequest(int sock);
 void clean_pathname(char *path);
+int handle_playlist(int sock, char *filename);
+int do_send(int sock, char *buf, int len);
+#if defined(USE_INTERNAL_SENDFILE_COPY) || defined(USE_INTERNAL_SENDFILE_MMAP)
+#define USE_INTERNAL_SENDFILE
+ssize_t internal_sendfile(int dst, int src, off_t *offset, size_t size);
+#endif
+
+
 
 #define log(format, args...)					\
 	do {							\
@@ -45,4 +56,15 @@ void clean_pathname(char *path);
 			fprintf(stderr, format "\n", args);	\
 	} while(0)
 
+#define logv(format, args...)					\
+	do {							\
+		if (v_opt) {					\
+			if (d_opt)				\
+				syslog(LOG_WARNING, format, args);\
+			else					\
+				fprintf(stderr, format "\n", args);\
+		}						\
+	} while(0)
+
+#define min(a, b) (((a) < (b)) ? (a) : (b))
 #define max(a, b) (((a) > (b)) ? (a) : (b))
